Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrEmpty = errors.New("empty schema") ErrMismatch = errors.New("schema mismatch") )
Functions ¶
This section is empty.
Types ¶
type Schema ¶
func (Schema) Equal ¶
Equal reports whether two schemas contain the same key/value pairs. Values are compared using ==.
func (Schema) Intersection ¶
Intersection returns a new schema with the common key/value pairs of s and t.
func (Schema) IsSubsetOf ¶
Click to show internal directories.
Click to hide internal directories.